Word

Struct Word 

pub struct Word {
    pub syllables: Vec<Syllable>,
}

Fields

syllables: Vec<Syllable>

Implementations

Source

impl Word

pub fn new<I>(text: I, aliases: &[Transformation]) -> Result<Self, ASCAError>
where I: Into<String>,

pub fn get_syll_segments(&self, syll_index: usize) -> Option<&VecDeque<Segment>>

pub fn get_syll_segments_mut( &mut self, syll_index: usize, ) -> Option<&mut VecDeque<Segment>>

pub fn remove_syll(&mut self, syll_index: usize)

Removes and returns the syllable at syll_index within the word, shifting all elements after it to the left.

Panics

Panics if syll_index is out of bounds.

pub fn swap_sylls(&mut self, a: usize, b: usize)

Swaps two syllable in the word.

If a equals to b, it’s guaranteed that elements won’t change value.

Arguments
  • a - The index of the first syllable
  • b - The index of the second syllable
Panics

Panics if a or b are out of bounds.

pub fn seg_length_at(&self, seg_index: SegPos) -> usize

Finds number of consecutive identical segments within a syllable starting from the given index.
Does not take into account if said index is in the middle of the repetition

Panics

If SegPos is out of bounds