pub struct Word {
pub syllables: Vec<Syllable>,
}Fields
syllables: Vec<Syllable>Implementations
Sourceimpl Word
impl Word
pub fn new<I>(text: I, aliases: &[Transformation]) -> Result<Self, ASCAError>
pub fn get_syll_segments(&self, syll_index: usize) -> Option<&VecDeque<Segment>>
pub fn get_syll_segments_mut( &mut self, syll_index: usize, ) -> Option<&mut VecDeque<Segment>>
Sourcepub fn remove_syll(&mut self, syll_index: usize)
pub fn remove_syll(&mut self, syll_index: usize)
Removes and returns the syllable at syll_index within the word, shifting all elements after it to the left.
Panics
Panics if syll_index is out of bounds.
Sourcepub fn swap_sylls(&mut self, a: usize, b: usize)
pub fn swap_sylls(&mut self, a: usize, b: usize)
Sourcepub fn seg_length_at(&self, seg_index: SegPos) -> usize
pub fn seg_length_at(&self, seg_index: SegPos) -> usize
Finds number of consecutive identical segments within a syllable starting from the given index.
Does not take into account if said index is in the middle of the repetition
Panics
If SegPos is out of bounds